﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.IO;

namespace ClientDesktop
{
    public partial class FormMain : Form
    {
        public FormMain()
        {
            InitializeComponent();

            comboBoxInstancesSQL.SelectedIndex = 0;
        }

        private void quitterToolStripMenuItem_Click(object sender, EventArgs e)
        {
            Application.Exit();
        }

        private void MSG_OK()
        {
            MessageBox.Show(this, "Appel effectué", "Information", MessageBoxButtons.OK, MessageBoxIcon.Information);
        }

        private void MSG_ERROR(Exception exception)
        {
            MessageBox.Show(this, exception.ToString(), "Erreur", MessageBoxButtons.OK, MessageBoxIcon.Error);
        }

        private void CURSOR_WAIT()
        {
            this.Cursor = Cursors.WaitCursor;
            Application.DoEvents();
        }

        private void CURSOR_DEFAULT()
        {
            this.Cursor = Cursors.Default;
        }

        private void RemplirListBox(DataSet monDataSet)
        {
            listBoxListeDesLivres.DataSource = monDataSet.Tables["ListeDesLivres"];
            listBoxListeDesLivres.DisplayMember = "Titre";
        }

        private void sQLServer2008ToolStripMenuItem_Click(object sender, EventArgs e)
        {
            CURSOR_WAIT();

            try
            {
                string chaineConnexion = string.Format(Properties.Settings.Default.ChaineConnexion, comboBoxInstancesSQL.Text, textBoxLogin.Text, textBoxMotDePasse.Text);

                DataSet monDataSet = Librairie.Utils.SQLServer2008(
                      chaineConnexion
                    , decimal.Parse(textBoxPrixMinimum.Text)
                    , decimal.Parse(textBoxPrixMaximum.Text));

                RemplirListBox(monDataSet);

                MSG_OK();
            }
            catch (Exception exception)
            {
                MSG_ERROR(exception);
            }

            CURSOR_DEFAULT();
        }


        private void webServiceXMLtoolStripMenuItem_Click(object sender, EventArgs e)
        {
            CURSOR_WAIT();

            try
            {
                DataSet monDataSet = new MesServices.WebServiceSoapClient().SQLServer2008(
                      textBoxLogin.Text
                    , textBoxMotDePasse.Text
                    , decimal.Parse(textBoxPrixMinimum.Text)
                    , decimal.Parse(textBoxPrixMaximum.Text));

                RemplirListBox(monDataSet);

                MSG_OK();
            }
            catch (Exception exception)
            {
                MSG_ERROR(exception);
            }

            CURSOR_DEFAULT();
        }

        private void SynchroniserToolStripMenuItem_Click(object sender, EventArgs e)
        {
            CURSOR_WAIT();

            try
            {
                string sdfFile = Path.Combine(Application.CommonAppDataPath, "maBase.sdf");

                Librairie.Utils.Synchroniser(sdfFile);

                MSG_OK();
            }
            catch (Exception exception)
            {
                MSG_ERROR(exception);
            }

            CURSOR_DEFAULT();
        }

        private void sQLServerCompactEditionToolStripMenuItem_Click(object sender, EventArgs e)
        {
            CURSOR_WAIT();

            try
            {
                string sdfFile = Path.Combine(Application.CommonAppDataPath, "maBase.sdf");
                string chaineConnexion = string.Format("Data Source={0}", sdfFile);

                DataSet monDataSet = Librairie.Utils.SQLServerCompactEdition(
                      chaineConnexion
                    , decimal.Parse(textBoxPrixMinimum.Text)
                    , decimal.Parse(textBoxPrixMaximum.Text));

                RemplirListBox(monDataSet);

                MSG_OK();
            }
            catch (Exception exception)
            {
                MSG_ERROR(exception);
            }

            CURSOR_DEFAULT();
        }
    }
}
