﻿using System;
using System.Linq;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.IO;

namespace ClientPDA
{
    public partial class FormMain : Form
    {
        public FormMain()
        {
            InitializeComponent();

            WINS.Utils.Publish("WIN2008-BELAUD", "192.168.0.36");

            comboBoxInstancesSQL.SelectedIndex = 0;
        }

        private void quitterToolStripMenuItem_Click(object sender, EventArgs e)
        {
            Application.Exit();
        }

        private void MSG_OK()
        {
            MessageBox.Show("Appel effectué", "Information", MessageBoxButtons.OK, MessageBoxIcon.Asterisk, MessageBoxDefaultButton.Button1);
        }

        private void MSG_ERROR(Exception exception)
        {
            MessageBox.Show(exception.ToString(), "Erreur", MessageBoxButtons.OK, MessageBoxIcon.Hand, MessageBoxDefaultButton.Button1);
        }

        private void CURSOR_WAIT()
        {
            Cursor.Current = Cursors.WaitCursor;
            Application.DoEvents();
        }

        private void CURSOR_DEFAULT()
        {
            Cursor.Current = Cursors.Default;
        }

        private void RemplirListBox(DataSet monDataSet)
        {
            listBoxListeDesLivres.DataSource = monDataSet.Tables["ListeDesLivres"];
            listBoxListeDesLivres.DisplayMember = "Titre";
        }

        private void sQLServer2008ToolStripMenuItem_Click(object sender, EventArgs e)
        {
            CURSOR_WAIT();

            try
            {
                string chaineConnexion = string.Format(Properties.Settings.Default.ChaineConnexion, comboBoxInstancesSQL.Text, textBoxLogin.Text, textBoxMotDePasse.Text);

                DataSet monDataSet = Librairie.Utils.SQLServer2008(
                      chaineConnexion
                    , decimal.Parse(textBoxPrixMinimum.Text)
                    , decimal.Parse(textBoxPrixMaximum.Text));

                RemplirListBox(monDataSet);

                MSG_OK();
            }
            catch (Exception exception)
            {
                MSG_ERROR(exception);
            }

            CURSOR_DEFAULT();
        }


        private void webServiceXMLtoolStripMenuItem_Click(object sender, EventArgs e)
        {
            CURSOR_WAIT();

            try
            {
                DataSet monDataSet = new MesServices.WebService().SQLServer2008(
                      textBoxLogin.Text
                    , textBoxMotDePasse.Text
                    , decimal.Parse(textBoxPrixMinimum.Text)
                    , decimal.Parse(textBoxPrixMaximum.Text));

                RemplirListBox(monDataSet);

                MSG_OK();
            }
            catch (Exception exception)
            {
                MSG_ERROR(exception);
            }

            CURSOR_DEFAULT();
        }

        private void SynchroniserToolStripMenuItem_Click(object sender, EventArgs e)
        {
            CURSOR_WAIT();

            try
            {
                string sdfFile = Path.Combine(MyApplication.CommonAppDataPath, "maBase.sdf");

                Librairie.Utils.Synchroniser(sdfFile);

                MSG_OK();
            }
            catch (Exception exception)
            {
                MSG_ERROR(exception);
            }

            CURSOR_DEFAULT();
        }

        private void sQLServerCompactEditionToolStripMenuItem_Click(object sender, EventArgs e)
        {
            CURSOR_WAIT();

            try
            {
                string sdfFile = Path.Combine(MyApplication.CommonAppDataPath, "maBase.sdf");
                string chaineConnexion = string.Format("Data Source={0}", sdfFile);

                DataSet monDataSet = Librairie.Utils.SQLServerCompactEdition(
                      chaineConnexion
                    , decimal.Parse(textBoxPrixMinimum.Text)
                    , decimal.Parse(textBoxPrixMaximum.Text));

                RemplirListBox(monDataSet);

                MSG_OK();
            }
            catch (Exception exception)
            {
                MSG_ERROR(exception);
            }

            CURSOR_DEFAULT();
        }
    }
}